@@ -27,14 +27,14 @@ from werkzeug.security import generate_password_hash
 
 from airflow.api_connexion.exceptions import AlreadyExists, BadRequest, NotFound, Unknown
 from airflow.api_connexion.parameters import check_limit, format_parameters
-from airflow.api_connexion.schemas.user_schema import (
+from airflow.api_connexion.security import requires_access_custom_view
+from airflow.providers.fab.auth_manager.models import User
+from airflow.providers.fab.auth_manager.schemas.user_schema import (
     UserCollection,
     user_collection_item_schema,
     user_collection_schema,
     user_schema,
 )
-from airflow.api_connexion.security import requires_access_custom_view
-from airflow.providers.fab.auth_manager.models import User
 from airflow.providers.fab.auth_manager.security_manager.override import FabAirflowSecurityManagerOverride
 from airflow.security import permissions
 from airflow.www.extensions.init_auth_manager import get_auth_manager
@@ -65,7 +65,7 @@ def get_users(*, limit: int, order_by: str = "id", offset: str | None = None) ->
     to_replace = {"user_id": "id"}
     order_param = order_by.strip("-")
     order_param = to_replace.get(order_param, order_param)
-    allowed_filter_attrs = [
+    allowed_sort_attrs = [
         "id",
         "first_name",
         "last_name",
@@ -74,7 +74,7 @@ def get_users(*, limit: int, order_by: str = "id", offset: str | None = None) ->
         "is_active",
         "role",
     ]
-    if order_by not in allowed_filter_attrs:
+    if order_by not in allowed_sort_attrs:
         raise BadRequest(
             detail=f"Ordering with '{order_by}' is disallowed or "
             f"the attribute does not exist on the model"
